import { Breadcrumb, Layout, Menu, Dropdown, Button } from "antd";
import React, { useEffect, useState } from "react";
import { adminRoutes } from "../../routers/routers";
import { useNavigate } from "react-router-dom";
import "./frame.css";
import { Lunar } from "lunar-javascript";
import { clearToken } from "../../utils/auth";

const { Header, Content, Footer } = Layout;

const items_header = adminRoutes.map((route) => ({
  key: "/admin" + route.path,
  label: route.label,
}));




function Frame(props) {
  const navigate = useNavigate();

  const [dateTime, setDateTime] = useState(new Date());

  const [lunarDate, setLunarDate] = useState("");
  //右边角色信息栏的数据
  const items = [
    {
      key: "myinf",
      label: <a>我的</a>,
    },
    {
      key: "logout",
      label: <a
        onClick={() => {
          clearToken();
          navigate('/login');
        }}
      >退出登录</a>,
    },
  ];

  useEffect(() => {
    const timer = setInterval(() => {
      const now = new Date();
      setDateTime(now);

      // 创建 Lunar 实例
      const lunarInfo = Lunar.fromDate(now);
      setLunarDate(
        `${lunarInfo.getMonthInChinese()}月${lunarInfo.getDayInChinese()}`
      );
    }, 1000);

    return () => clearInterval(timer);
  }, []);

  const formatDate = (date) => {
    return `${date.getFullYear()}.${date.getMonth() + 1}.${date.getDate()}`;
  };

  const formatTime = (date) => {
    const days = ["日", "一", "二", "三", "四", "五", "六"];
    return (
      <>
        {date.toLocaleTimeString()} <br />
        星期{days[date.getDay()]}
      </>
    );
  };

  return (
    <Layout>
      <Header className="headmenu">
        <Menu
          //   theme="dark"
          mode="horizontal"
          defaultSelectedKeys={["2"]}
          items={items_header}
          onClick={(p) => {
            navigate(p.key);
          }}
          style={{
            marginLeft: "15%", // 右移15
            gap: "20px",
            // borderBottom: "1px solid #d9d9d9"
          }}
        />
        <div style={{ display: "flex", gap: "10px", marginLeft: "105px" }}>
          <div className="child-box">
            阳历
            <br />
            {formatDate(dateTime)}
          </div>
          <div className="child-box">
            农历
            <br />
            {lunarDate}
          </div>
          <div className="child-box">无</div>
          <div className="child-box">{formatTime(dateTime)}</div>
        </div>
        {/* 这里dropdown的使用，显示的仅仅是button，交互之后才会显示dropdown的内容，所以直接修改button */}
        <Dropdown
          menu={{
            items,
          }}
          placement="bottom"
          arrow={{
            pointAtCenter: true,
          }}
        >
          <Button
            style={{
              margin: "60px",
              borderRadius: "20px",
              height: "40px",
              minWidth: "135px",
              padding: "10px 20px",
            }}
          >
            种植者角色
          </Button>
        </Dropdown>
      </Header>
      <Content
        className="site-layout"
        style={{
          backgroundColor: "white",
        }}
      >
        <div
          className="site-layout-background"
          style={{
            padding: 24,
            minHeight: 380,
          }}
        >
          {props.children}
        </div>
      </Content>
    </Layout>
  );
}

export default Frame;
